==> oxide-qt_1.17.9.orig.tar.xz: oxide-qt-1.17.9/ash/shell/content/client/shell_browser_main_parts.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_SHELL_CONTENT_CLIENT_EXAMPLES_BROWSER_MAIN_PARTS_H_
#define ASH_SHELL_CONTENT_CLIENT_EXAMPLES_BROWSER_MAIN_PARTS_H_

#include <memory>

#include "base/macros.h"
#include "content/public/browser/browser_main_parts.h"

namespace base {
class Thread;
}

namespace content {
class ShellBrowserContext;
struct MainFunctionParams;
}

namespace net {
class NetLog;
}

namespace views {
class ViewsDelegate;
}

namespace wm {
class WMState;
}

namespace ash {
namespace shell {

class ShellDelegateImpl;
class WindowWatcher;

class ShellBrowserMainParts : public content::BrowserMainParts {
 public:
  explicit ShellBrowserMainParts(const content::MainFunctionParams& parameters);
  ~ShellBrowserMainParts() override;

  // Overridden from content::BrowserMainParts:
  void PreMainMessageLoopStart() override;
  void PostMainMessageLoopStart() override;
  void ToolkitInitialized() override;
  void PreMainMessageLoopRun() override;
  bool MainMessageLoopRun(int* result_code) override;
  void PostMainMessageLoopRun() override;

  content::ShellBrowserContext* browser_context() {
    return browser_context_.get();
  }

 private:
  std::unique_ptr<net::NetLog> net_log_;
  std::unique_ptr<content::ShellBrowserContext> browser_context_;
  std::unique_ptr<views::ViewsDelegate> views_delegate_;
  std::unique_ptr<ash::shell::WindowWatcher> window_watcher_;
  ShellDelegateImpl* delegate_;  // owned by Shell
  std::unique_ptr<wm::WMState> wm_state_;

  DISALLOW_COPY_AND_ASSIGN(ShellBrowserMainParts);
};

}  // namespace shell
}  // namespace ash

#endif  // ASH_SHELL_CONTENT_CLIENT_EXAMPLES_BROWSER_MAIN_PARTS_H_

==> oxide-qt_1.21.5.orig.tar.xz: oxide-qt-1.21.5/ash/shell/content/client/shell_browser_main_parts.h <==
// Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef ASH_SHELL_CONTENT_CLIENT_EXAMPLES_BROWSER_MAIN_PARTS_H_
#define ASH_SHELL_CONTENT_CLIENT_EXAMPLES_BROWSER_MAIN_PARTS_H_

#include <memory>

#include "base/macros.h"
#include "content/public/browser/browser_main_parts.h"

namespace content {
class ShellBrowserContext;
struct MainFunctionParams;
}

namespace net {
class NetLog;
}

namespace views {
class ViewsDelegate;
}

namespace wm {
class WMState;
}

namespace ash {
namespace shell {

class ExampleAppListPresenter;
class ShellDelegateImpl;
class WindowWatcher;

class ShellBrowserMainParts : public content::BrowserMainParts {
 public:
  explicit ShellBrowserMainParts(const content::MainFunctionParams& parameters);
  ~ShellBrowserMainParts() override;

  // Overridden from content::BrowserMainParts:
  void PreMainMessageLoopStart() override;
  void PostMainMessageLoopStart() override;
  void ToolkitInitialized() override;
  void PreMainMessageLoopRun() override;
  bool MainMessageLoopRun(int* result_code) override;
  void PostMainMessageLoopRun() override;

  content::ShellBrowserContext* browser_context() {
    return browser_context_.get();
  }

 private:
  std::unique_ptr<net::NetLog> net_log_;
  std::unique_ptr<content::ShellBrowserContext> browser_context_;
  std::unique_ptr<views::ViewsDelegate> views_delegate_;
  std::unique_ptr<ash::shell::WindowWatcher> window_watcher_;
  ShellDelegateImpl* delegate_;  // owned by Shell
  std::unique_ptr<wm::WMState> wm_state_;
  std::unique_ptr<ExampleAppListPresenter> example_app_list_presenter_;

  DISALLOW_COPY_AND_ASSIGN(ShellBrowserMainParts);
};

}  // namespace shell
}  // namespace ash

#endif  // ASH_SHELL_CONTENT_CLIENT_EXAMPLES_BROWSER_MAIN_PARTS_H_
